@@ -1,11 +1,11 @@
 import json
 import logging
 import os
+from dataclasses import dataclass
 from datetime import datetime
 from typing import List
 
 import requests
-from pydantic import BaseModel
 
 TELENET_DATETIME_FORMAT = "%Y-%m-%dT%H:%M:%S.0%z"
 
@@ -14,10 +14,11 @@ logger = logging.getLogger("telemeter")
 
 
 def _kibibyte_to_gibibyte(kib):
-    return kib / (2 ** 20)
+    return kib / (2**20)
 
 
-class UsageDay(BaseModel):
+@dataclass
+class UsageDay(object):
     """Represents a day of internet usage"""
 
     date: datetime
@@ -38,7 +39,8 @@ class UsageDay(BaseModel):
             return f"{date_str}: {usage_gib:4.2f} GiB"
 
 
-class TelenetProductUsage(BaseModel):
+@dataclass
+class TelenetProductUsage(object):
     product_type: str
     squeezed: bool
     period_start: datetime
@@ -66,10 +68,9 @@ class TelenetProductUsage(BaseModel):
         peak_usage = data["totalusage"].get("peak", 0)
         offpeak_usage = data["totalusage"].get("offpeak", 0)
 
-        included_usage = data["totalusage"].get("includedvolume", 0)
-        extended_usage = data["totalusage"].get("extendedvolume", 0)
-
-        total_usage = peak_usage + offpeak_usage + included_usage + extended_usage
+        included_volume = data.get("includedvolume", 0) + data.get(
+            "extendedvolume", {}
+        ).get("volume", 0)
 
         return cls(
             product_type=data["producttype"],
@@ -78,10 +79,10 @@ class TelenetProductUsage(BaseModel):
                 data["periodstart"], TELENET_DATETIME_FORMAT
             ),
             period_end=datetime.strptime(data["periodend"], TELENET_DATETIME_FORMAT),
-            included_volume=data["includedvolume"],
+            included_volume=included_volume,
             peak_usage=peak_usage,
             offpeak_usage=offpeak_usage,
-            total_usage=total_usage,
+            total_usage=peak_usage + offpeak_usage,
             daily_usage=days,
         )
 
@@ -96,7 +97,8 @@ class TelenetProductUsage(BaseModel):
             return f"Usage for {self.product_type}: {usage_gib:4.2f} GiB of {included_gib:4.2f} GiB"
 
 
-class Telemeter(BaseModel):
+@dataclass
+class Telemeter(object):
     period_start: datetime
     period_end: datetime
     products: List[TelenetProductUsage]
@@ -120,7 +122,9 @@ class Telemeter(BaseModel):
 class TelenetSession(object):
     def __init__(self):
         self.s = requests.Session()
-        self.s.headers["User-Agent"] = "TelemeterPython/3"
+        self.s.headers[
+            "User-Agent"
+        ] = "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/100.0.4896.127 Safari/537.36"
 
     def login(self, username, password):
         # Get OAuth2 state / nonce
@@ -157,15 +161,6 @@ class TelenetSession(object):
 
         self.s.headers["X-TOKEN-XSRF"] = self.s.cookies.get("TOKEN-XSRF")
 
-        r = self.s.get(
-            "https://api.prd.telenet.be/ocapi/oauth/userdetails",
-            headers={
-                "x-alt-referer": "https://www2.telenet.be/nl/klantenservice/#/pages=1/menu=selfservice",
-            },
-            timeout=10,
-        )
-        assert r.status_code == 200
-
     def userdetails(self):
         r = self.s.get(
             "https://api.prd.telenet.be/ocapi/oauth/userdetails",
